@@ -196,8 +196,9 @@
       Main:Do
   !    if (verbose==1) write(*,*)'iteration',ni   !**
         call deriva(b,m,v,rl,namefunc)
- !     if (verbose==1) write(*,*)'loglik=',rl     !**
+ !     if (verbose==1)  write(*,*)'loglik=',rl     !**
   !    if (verbose==1) write(*,*)'parms',b        !**    
+
         rl1=rl
         dd = 0.d0
         fu=0.D0
@@ -249,22 +250,29 @@
               fu(ii)=da*ga*tr
            endif
         end do
-        call dchole(fu,m,nql,idpos)
-        !print*,"apres dchole "," range fu=",minval(fu),maxval(fu),"idpos=",idpos !**
-        if (idpos.ne.0) then
+
+         call dchole(fu,m,nql,idpos)
+      
+         if (idpos.ne.0) then
            ncount=ncount+1
+           if (ncount.gt.3000) then 
+              !print*,"ncount=",ncount
+              istop=4 
+              rl=-1.d9
+              goto 110
+           end if
            if (ncount.le.3.or.ga.ge.1.d0) then
               da=da*dm
            else
               ga=ga*dm
               if (ga.gt.1.d0) ga=1.d0
            endif
-           goto 400   !** peut tourner en boucle !!
+           goto 400   
         else
             do i=1,m
                delta(i)=fu(nfmax+i)
                b1(i)=b(i)+delta(i)
-            end do
+           end do
             rl=namefunc(b1,m,id,z,jd,z)
             if (rl1.lt.rl) then
                if(da.lt.eps) then
@@ -285,12 +293,12 @@
          endif
          step=dlog(1.5d0)
   !    write(*,*) 'searpas'         !**
-  !    print*,"vw=",vw,"step=",step,"b=",b,"bh=",bh,"m=",m,"delta=",delta,"fi=",fi    !**
+
          call searpas(vw,step,b,bh,m,delta,fi,namefunc)
          rl=-fi
          if(rl.eq.-1.D9) then
                istop=4
- !             write(*,*)'searpas problem' ,ni  !**
+  !            write(*,*)'searpas problem' ,ni  !**
                goto 110
           end if
 
@@ -380,6 +388,8 @@
             exit Main
          end if
          vl=(fcith(i)-temp)/(2.d0*(-thn))
+!print*,"deriva i=",i,"thn",thn,"fcith",fcith(i),"temp",temp
+!print*,"vl=",vl
          v(ll)=vl
          do j=1,i
             k=k+1
